@@ -319,11 +319,7 @@ def augment_and_train(model, GCS_DS_PATH, train_tfrec_path, val_tfrec_path, batc
 
 
 
-if __name__ == "__main__":
-	pass
-else:
-
-
+if __name__ != "__main__":
 	global LR_MAX
 	global LR_MIN
 	global LR_RAMPUP_EPOCHS
@@ -343,4 +339,4 @@ else:
 	LR_SUSTAIN_EPOCHS = 0
 	LR_EXP_DECAY = 0.8
 	LR_START = 0.00001
-	import tensorflow.keras.backend as K
\ No newline at end of file
+	import tensorflow.keras.backend as K
